<!-- MD+:META
title = "Pakk usage and developer documentation."
 -->

# Documentation Contents

<!-- MD+:generate.content
header = ''
level = 1
dirs = True
md_files = True
-->
|Directory                                             |Content                            |
|------------------------------------------------------|-----------------------------------|
|[`connecting_to_gitlab.md`](connecting_to_gitlab.md)  |How to connect to GitLab           |
|[`creating_packages.md`](creating_packages.md)        |Creating Packages                  |
|[`developing_connectors.md`](developing_connectors.md)|Developing new Connectors          |
|[`developing_setups.md`](developing_setups.md)        |TODO: Developing Setup Routines    |
|[`developing_types.md`](developing_types.md)          |TODO: Integrating new Pakkage Types|
|[`examples`](examples)                                |Examples for pakk developers       |
|[`using_pakk.md`](using_pakk.md)                      |How to use pakk                    |
<!-- MD+FIN:generate.content -->




# Developer FAQ

- TODO: My developed connector is not found by pakk
